@@ -55,15 +55,13 @@ bme_net.load_cifar_10_dataset()
 ## display network properties
 number_of_learnable_params = sum(p.numel() for p in bme_net.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
-num_layers = len(list(bme_net.parameters()))
-print("\nThe number of layers in the model: %d" % num_layers)
-
 
 ## training and testing
 bme_net.run_code_for_training(bme_net, display_images=False)
 
-import pymsgbox      
-response = pymsgbox.confirm("Finished training.  Start testing on unseen data?") 
-if response == "OK":   
-    bme_net.run_code_for_testing(bme_net, display_images=False)
+#import pymsgbox      
+#response = pymsgbox.confirm("Finished training.  Start testing on unseen data?") 
+#if response == "OK":   
+
+bme_net.run_code_for_testing(bme_net, display_images=False)
 
