@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.5.2'
+__version__   = '2.5.4'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2025-March-26'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.2.html'
+__date__      = '2025-May-4'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.4.html'
 __copyright__ = "(C) 2025 Avinash Kak. Python Software Foundation."
 
 
